# First you need to install the following pacman package
install.packages("pacman")

# Load (and installed if neeeded) libraries
pacman::p_load(haven, tidyverse, dosresmeta, rms, scales, metafor)

# Load the data
rm(list=ls())
coffee_mort <- read_dta("http://www.stats4life.se/data/coffee_mortality.dta")
data("coffee_mort")

##########################################
# Analysis of one study by Klasky et al.##
##########################################

Klasky <- filter(coffee_mort, id ==3)

# Linear dose-response
doseresKlasky <- dosresmeta(formula = logrr ~ dose, id = id, type = type,
                            cases = cases, n = n, se = se, data = Klasky)
summary(doseresKlasky)

# Quadratic dose-response
doseres2Klasky <- dosresmeta(formula = logrr ~ dose + I(dose^2), id = id, 
                            type = type,cases = cases, n = n, se = se,
                            data = Klasky)
summary(doseres2Klasky)

# Restricted cubic splines
summary(coffee_mort$dose)
knots <- c(0.495, 2, 4.5)
doseres3Klasky <- dosresmeta(formula = logrr ~ rcs(dose, knots), id = id, 
                             type = type, cases = cases, n = n, se = se, 
                             data = Klasky)
summary(doseres3Klasky)


# Figure for Klasky study
# -------------------------

# Plot step function
Klasky_p <- ggplot(Klasky, aes(x = c(0, 0, 1, 3, 7), xend = c(0, 1,3,7,9), 
                   y = exp(logrr), yend = exp(logrr))) +
  geom_segment() +
  geom_point(aes(x = dose, size = n/1000), shape = 21) +
  geom_hline(yintercept = 1, linetype = "dotted", col = "green") +
  labs(x = "Dose cap/day", y = "RR") +
  guides(size = FALSE) +
  scale_y_continuous(trans = "log", breaks = pretty_breaks()) +
  theme_classic()
Klasky_p

# Adding prediction for different models
pred <- data.frame(dose = seq(0, 8, .1)) %>%
  cbind(lin = predict(doseresKlasky, newdata = ., expo = TRUE),
        quadr = predict(doseres2Klasky, newdata = ., expo = TRUE),
        spl = predict(doseres3Klasky, newdata = ., expo = TRUE)
  )

Klasky_p +
  geom_line(data = pred, aes(x = dose, y = lin.pred, xend = NULL, yend = NULL, 
                             lty = "Linear", col = "Linear")) +
  geom_line(data = pred, aes(x = dose, y = quadr.pred, xend = NULL, yend = NULL, 
                             lty = "Quadratic", col = "Quadratic")) +
  geom_line(data = pred, aes(x = dose, y = spl.pred, xend = NULL, yend = NULL, 
                             lty = "RCS", col = "RCS")) +
  scale_linetype_manual(name = "Model",values= c('solid', 'solid', 'dotdash'))+
  scale_colour_manual(name = "Model", values = c("blue", "green","red"))



#########################################
# Meta-analysis for 22 studies         ##
#########################################

# Meta-analysis of linear shape
doseres = dosresmeta(formula = logrr ~ dose, id = id, type = type, cases = cases,
                     n = n, se = se, data = coffee_mort)
summary(doseres)

# Meta-analysis of study-specific slopes
dat_meta <- data.frame(
  author = with(coffee_mort, unique(paste(author, gender))),
  bi = unname(doseres$bi),
  si = unlist(doseres$Si)
)
  
meta_mod <- rma.uni(yi = bi, sei = si, slab = author, data = dat_meta, method = "REML")
meta_mod
forest(meta_mod)

# Meta-analysis of splines shape
doseres3 = dosresmeta(formula = logrr ~ rcs(dose, knots), id = id, type = type,
                      cases = cases, n = n, se = se, data = coffee_mort)
summary(doseres3)

# Plot meta-analysis with splines
pred2 <- data.frame(dose = seq(0, 8, .1)) %>%
  cbind(predict(doseres3, newdata = ., expo = T))

ggplot(pred2, aes(dose, pred, ymin = ci.lb, ymax = ci.ub)) + 
  geom_line() + 
  geom_ribbon(alpha = .1, linetype = "dotted") + 
  scale_y_continuous(trans = "log", breaks = pretty_breaks()) +
  labs(x = "Dose cap/day", y = "RR") +
  theme_classic() 

# Table 2
filter(pred2, dose %in% 0:8)
